<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Открепить</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Док</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Принудительно Завершить</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрыть Всё</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Открепить</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Закрепить</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Принудительный выход</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрыть все</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
